@@ -1,11 +1,10 @@
 """Module contains the main question function to create a confirm prompt."""
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Tuple, Union
 
 from prompt_toolkit.keys import Keys
 from prompt_toolkit.shortcuts import PromptSession
 
 from InquirerPy.base import BaseSimplePrompt
-from InquirerPy.enum import INQUIRERPY_KEYBOARD_INTERRUPT
 from InquirerPy.exceptions import InvalidArgument
 from InquirerPy.utils import InquirerPyStyle, SessionResult
 
@@ -17,18 +16,15 @@ class ConfirmPrompt(BaseSimplePrompt):
 
     This class is used for confirm prompt.
 
-    :param message: the question message to display
-    :type message: Union[str, Callable[[SessionResult], str]]
-    :param style: the style dictionary to apply
-    :type style: InquirerPyStyle
-    :param default: set default answer to true
-    :type default: Union[bool, Callable[[Dict[str, Any]], bool]]
-    :param qmark: the custom qmark to display infront of the question
-    :type qmark: str
-    :param transformer: a callable to transform the result, this is visual effect only
-    :type transformer: Callable[[bool], Any]
-    :param filter: a callable to filter the result, updating the user input before returning the result
-    :type filter: Callable[[bool], Any]
+    :param message: The question message to display.
+    :param style: The style dictionary to apply.
+    :param default: Set default answer value.
+    :param qmark: The custom symbol to display infront of the question before its answered.
+    :param amark: THe custom symbol to display infront of the question after its answered.
+    :param instruction: Instruction to display after the question message.
+    :param transformer: A callable to transform the result, this is visual effect only.
+    :param filter: A callable to filter the result, updating the user input before returning the result.
+    :param wrap_lines: Soft wrap question lines when question exceeds the terminal width.
     """
 
     def __init__(
@@ -37,29 +33,38 @@ class ConfirmPrompt(BaseSimplePrompt):
         style: InquirerPyStyle = None,
         default: Union[bool, Callable[[Dict[str, Any]], bool]] = False,
         qmark: str = "?",
+        amark: str = "?",
+        instruction: str = "",
         transformer: Callable[[bool], Any] = None,
         filter: Callable[[bool], Any] = None,
+        wrap_lines: bool = True,
+        confirm_letter: str = "y",
+        reject_letter: str = "n",
         session_result: SessionResult = None,
         **kwargs
     ) -> None:
-        """Construct a PromptSession object and apply keybindings."""
         super().__init__(
             message=message,
             style=style,
             vi_mode=False,
             qmark=qmark,
+            amark=amark,
+            instruction=instruction,
             transformer=transformer,
             filter=filter,
-            session_result=session_result,
             default=default,
+            wrap_lines=wrap_lines,
+            session_result=session_result,
         )
         if not isinstance(self._default, bool):
             raise InvalidArgument(
                 "default for confirm type question should be type of bool."
             )
+        self._confirm_letter = confirm_letter
+        self._reject_letter = reject_letter
 
-        @self._kb.add("y")
-        @self._kb.add("Y")
+        @self._kb.add(self._confirm_letter)
+        @self._kb.add(self._confirm_letter.upper())
         def confirm(event) -> None:
             """Bind y and Y to accept confirmation."""
             self._session.default_buffer.text = ""
@@ -67,8 +72,8 @@ class ConfirmPrompt(BaseSimplePrompt):
             self.status["result"] = True
             event.app.exit(result=True)
 
-        @self._kb.add("n")
-        @self._kb.add("N")
+        @self._kb.add(self._reject_letter)
+        @self._kb.add(self._reject_letter.upper())
         def reject(event) -> None:
             """Bind n and N to reject confirmation."""
             self._session.default_buffer.text = ""
@@ -92,6 +97,7 @@ class ConfirmPrompt(BaseSimplePrompt):
             message=self._get_prompt_message,
             key_bindings=self._kb,
             style=self._style,
+            wrap_lines=self._wrap_lines,
             input=kwargs.pop("input", None),
             output=kwargs.pop("output", None),
         )
@@ -102,28 +108,19 @@ class ConfirmPrompt(BaseSimplePrompt):
         After user select an answer, remove (Y/n) or (y/N) and inject
         the pretty answer.
 
-        :return: a list of formatted message to use for PromptSession
-        :rtype: List[Tuple[str, str]]
+        :return: A list of formatted message to be consumed by PromptSession.
         """
-        pre_answer = (
-            "class:instruction",
-            "%s" % " (Y/n)" if self._default else " (y/N)",
-        )
+        if not self.instruction:
+            pre_answer = (
+                "class:instruction",
+                " (%s/%s) " % (self._confirm_letter.upper(), self._reject_letter)
+                if self._default
+                else " (%s/%s) " % (self._confirm_letter, self._reject_letter.upper()),
+            )
+        else:
+            pre_answer = ("class:instruction", " %s " % self.instruction)
         post_answer = ("class:answer", " Yes" if self.status["result"] else " No")
         return super()._get_prompt_message(pre_answer, post_answer)
 
-    def execute(self, raise_keyboard_interrupt: bool = True) -> Optional[bool]:
-        """Display a confirm prompt and get user input for confirmation.
-
-        :return: user selected answer, either True or False
-        :rtype: bool
-        """
-        result = self._session.prompt()
-        if result == INQUIRERPY_KEYBOARD_INTERRUPT:
-            if raise_keyboard_interrupt:
-                raise KeyboardInterrupt
-            else:
-                result = None
-        if not self._filter:
-            return result
-        return self._filter(result)
+    def _run(self) -> bool:
+        return self._session.prompt()
