@@ -39,20 +39,19 @@ def get_style(
     style parameter -> ENV variable -> default style
 
     :param style: style to apply to prompt
-    :type style: Dict[str, str]
     :param style_override: override all default styles
-    :type style_override: bool
     :return: instance of InquirerPyStyle, consume it via `Style.from_dict(InquirerPyStyle.dict)`
-    :rtype: InquirerPyStyle
     """
     if not style_override or style is None:
         if not style:
             style = {}
         result = {
             "questionmark": os.getenv("INQUIRERPY_STYLE_QUESTIONMARK", "#e5c07b"),
+            "answermark": os.getenv("INQUIRERPY_STYLE_ANSWERMARK", "#e5c07b"),
             "answer": os.getenv("INQUIRERPY_STYLE_ANSWER", "#61afef"),
             "input": os.getenv("INQUIRERPY_STYLE_INPUT", "#98c379"),
             "question": os.getenv("INQUIRERPY_STYLE_QUESTION", ""),
+            "answered_question": os.getenv("INQUIRERPY_STYLE_ANSWERED_QUESTION", ""),
             "instruction": os.getenv("INQUIRERPY_STYLE_INSTRUCTION", ""),
             "pointer": os.getenv("INQUIRERPY_STYLE_POINTER", "#61afef"),
             "checkbox": os.getenv("INQUIRERPY_STYLE_CHECKBOX", "#98c379"),
@@ -69,9 +68,11 @@ def get_style(
     else:
         result = {
             "questionmark": os.getenv("INQUIRERPY_STYLE_QUESTIONMARK", ""),
+            "answermark": os.getenv("INQUIRERPY_STYLE_ANSWERMARK", ""),
             "answer": os.getenv("INQUIRERPY_STYLE_ANSWER", ""),
             "input": os.getenv("INQUIRERPY_STYLE_INPUT", ""),
             "question": os.getenv("INQUIRERPY_STYLE_QUESTION", ""),
+            "answered_question": os.getenv("INQUIRERPY_STYLE_ANSWERED_QUESTION", ""),
             "instruction": os.getenv("INQUIRERPY_STYLE_INSTRUCTION", ""),
             "pointer": os.getenv("INQUIRERPY_STYLE_POINTER", ""),
             "checkbox": os.getenv("INQUIRERPY_STYLE_CHECKBOX", ""),
@@ -97,6 +98,7 @@ def calculate_height(
     height: Optional[Union[int, str]],
     max_height: Optional[Union[int, str]],
     offset: int = 2,
+    wrap_lines_offset: int = 0,
 ) -> Tuple[Optional[int], int]:
     """Calculate the height and max_height for the choice window.
 
@@ -106,6 +108,12 @@ def calculate_height(
 
     If max_height is not provided or is None,
     set it to `60%` for best visual presentation in terminal.
+
+    :param height: The desired height in either percentage form or exact int form.
+    :param max_height: Max acceptable height in either percentage form or exact int form.
+    :param offset: Offset to apply to the height.
+    :param wrap_lines_offset: Additional offset that should be applied when wrapping lines.
+    :return: Tuple of desired height and max height.
     """
     try:
         _, term_lines = shutil.get_terminal_size()
@@ -116,7 +124,9 @@ def calculate_height(
             if isinstance(height, str):
                 height = height.replace("%", "")
                 height = int(height)
-                dimmension_height = math.floor(term_lines * (height / 100)) - offset
+                dimmension_height = (
+                    math.floor(term_lines * (height / 100)) - offset - wrap_lines_offset
+                )
             else:
                 dimmension_height = height
 
@@ -125,7 +135,9 @@ def calculate_height(
         if isinstance(max_height, str):
             max_height = max_height.replace("%", "")
             max_height = int(max_height)
-            dimmension_max_height = math.floor(term_lines * (max_height / 100)) - offset
+            dimmension_max_height = (
+                math.floor(term_lines * (max_height / 100)) - offset - wrap_lines_offset
+            )
         else:
             dimmension_max_height = max_height
 
